@@ -1,5 +1,3 @@
-import logging
-
 from SeleniumLibrary import SeleniumLibrary
 from SeleniumLibrary.keywords import BrowserManagementKeywords, ScreenshotKeywords, WaitingKeywords, \
                                      FormElementKeywords, ElementKeywords, JavaScriptKeywords
@@ -12,6 +10,7 @@ import os
 import socket
 import time
 from datetime import datetime
+from selenium.webdriver.firefox.options import FirefoxProfile
 
 from ftsa.core.properties import VERSION, REMOTE_VERSION, SLEEP_SECONDS, REC_VIDEO_VERSION
 from ftsa.core.utils import extract_name_from, extract_type_from, sanitize_camel_case, get_project_properties
@@ -58,10 +57,10 @@ class FTSASeleniumLibrary(SeleniumLibrary):
 
         # Configuring BROWSER OPTIONS
         browser_management = BrowserManagementKeywords(self)
+        profile = FirefoxProfile()
         if browser.lower() == 'firefox':
-            from selenium.webdriver.firefox.options import Options, FirefoxProfile
+            from selenium.webdriver.firefox.options import Options
             config_options = Options()
-            profile = FirefoxProfile(FirefoxProfile.DEFAULT_PREFERENCES)
             profile.set_preference("browser.download.folderList", 2)
             profile.set_preference("browser.download.manager.showWhenStarting", False)
             profile.set_preference("browser.download.dir", download_path)
@@ -96,9 +95,9 @@ class FTSASeleniumLibrary(SeleniumLibrary):
             raise RuntimeError(f'{browser} browser is not supported.')
 
         # Configuring MAXIMIZED
-        if maximized:
-            logger.info(f'Setting {browser.upper()} browser to open MAXIMIZED.')
-            config_options.add_argument('--start-maximized')
+        # if maximized:
+        #     logger.info(f'Setting {browser.upper()} browser to open MAXIMIZED.')
+        #     config_options.add_argument('--start-maximized')
         logger.info(f'Setting SELENIUM SPEED to "{speed}".')
         browser_management.set_selenium_speed(speed)
         logger.info(f'Setting SELENIUM TIMEOUT to "{timeout}".')
@@ -107,11 +106,20 @@ class FTSASeleniumLibrary(SeleniumLibrary):
         browser_management.set_selenium_implicit_wait(implicit_wait)
         # Open Browsing with/without remote URL
         if remote_url is not None and os.getenv('NO_DOCKER_EXECUTION') != 'nodocker':
-            browser_management.open_browser(url, browser, options=config_options, remote_url=remote_url)
+            if browser.lower() == 'firefox':
+                browser_management.open_browser(url, browser, remote_url=remote_url, ff_profile_dir=profile)
+            else:
+                browser_management.open_browser(url, browser, options=config_options, remote_url=remote_url)
             logger.info(f'Browser {browser.upper()} opened in remote url {remote_url}.')
         else:
-            browser_management.open_browser(url, browser, options=config_options)
+            if browser.lower() == 'firefox':
+                browser_management.open_browser(url, browser, ff_profile_dir=profile)
+            else:
+                browser_management.open_browser(url, browser, options=config_options)
             logger.info(f'Browser {browser.upper()} opened locally.')
+        if maximized:
+            self.maximize_browser_window()
+            logger.info(f'Setting {browser.upper()} browser to open MAXIMIZED.')
         return browser_management.get_title()
 
     @keyword
