@@ -1,8 +1,14 @@
 import os
 import text_unidecode
+
+from configparser import ConfigParser
 from robot.api import logger
 
 
+DIR_RESOURCES = 'resources'
+FILE_PROJECT_PROPERTIES = 'project.properties'
+
+
 def extract_type_from(locator):
     return locator.split(":")[0]
 
@@ -24,3 +30,10 @@ def execute(cmd: str):
     cmdlog = f'EXECUTED: "{cmd}" WITH RESULT {res}'
     logger.info(cmdlog)
     print(cmdlog)
+
+
+def get_project_properties():
+    project = ConfigParser()
+    project.read(os.path.join(os.getcwd(), DIR_RESOURCES, FILE_PROJECT_PROPERTIES))
+    return project
+
